==> ejc-budgetmanage-impl-3.0.0-20220401.121145-44-sources.jar: com/ejianc/business/bedget/vo/ConsdrawbudgettotalVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordconsdrawbudgettotalVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.bedget.vo.ConsdrawbudgettotaldetailVO;

/**
 * 施工预算图汇总表
 * 
 * @author generator
 * 
 */
public class ConsdrawbudgettotalVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.math.BigDecimal costTotal; // 造价合计
    private java.math.BigDecimal itemsSubTotal; // 分部分项合计
    private java.math.BigDecimal measureItemsTotal; // 措施项目合计
    private java.math.BigDecimal otherItemsTotal; // 其他项目合计
    private java.lang.Integer isOpenControl; // 是否开启控制:0 否，1:是
    private java.math.BigDecimal feesTotal; // 规费合计
    private java.math.BigDecimal taxTotal; // 税金合计
    private java.lang.String billCode; // 单据编码
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long operatorId; // 经办人id
    private java.lang.String operatorName; // 经办人名称
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.lang.Long sort; // 序号
    
    private List<ConsdrawbudgettotaldetailVO> consdrawbudgettotaldetailEntities = new ArrayList<>(); // 施工预算图汇总表子表
    private List<RecordconsdrawbudgettotalVO> recordconsdrawbudgettotalVOS = new ArrayList<>(); // 施工预算图汇总表子表

    /**
     * 造价合计
     */
    public java.math.BigDecimal getCostTotal() {
        return costTotal;
    }

    /**
     * 造价合计
     */
    public void setCostTotal(java.math.BigDecimal costTotal) {
        this.costTotal = costTotal;
    }
    /**
     * 分部分项合计
     */
    public java.math.BigDecimal getItemsSubTotal() {
        return itemsSubTotal;
    }

    /**
     * 分部分项合计
     */
    public void setItemsSubTotal(java.math.BigDecimal itemsSubTotal) {
        this.itemsSubTotal = itemsSubTotal;
    }
    /**
     * 措施项目合计
     */
    public java.math.BigDecimal getMeasureItemsTotal() {
        return measureItemsTotal;
    }

    /**
     * 措施项目合计
     */
    public void setMeasureItemsTotal(java.math.BigDecimal measureItemsTotal) {
        this.measureItemsTotal = measureItemsTotal;
    }
    /**
     * 其他项目合计
     */
    public java.math.BigDecimal getOtherItemsTotal() {
        return otherItemsTotal;
    }

    /**
     * 其他项目合计
     */
    public void setOtherItemsTotal(java.math.BigDecimal otherItemsTotal) {
        this.otherItemsTotal = otherItemsTotal;
    }
    /**
     * 是否开启控制:0 否，1:是
     */
    public java.lang.Integer getIsOpenControl() {
        return isOpenControl;
    }

    /**
     * 是否开启控制:0 否，1:是
     */
    public void setIsOpenControl(java.lang.Integer isOpenControl) {
        this.isOpenControl = isOpenControl;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    
     /**
      * 施工预算图汇总表子表
      */
     public List<ConsdrawbudgettotaldetailVO> getConsdrawbudgettotaldetailEntities() {
        return consdrawbudgettotaldetailEntities;
     }

     /**
      * 施工预算图汇总变更历史记录表
      */
     public void setConsdrawbudgettotaldetailEntities(List<ConsdrawbudgettotaldetailVO> consdrawbudgettotaldetailEntities) {
        this.consdrawbudgettotaldetailEntities = consdrawbudgettotaldetailEntities;
     }

    public List<RecordconsdrawbudgettotalVO> getRecordconsdrawbudgettotalVOS() {
        return recordconsdrawbudgettotalVOS;
    }

    /**
     * 施工预算图汇总变更历史记录表
     */
    public void setRecordconsdrawbudgettotalVOS(List<RecordconsdrawbudgettotalVO> recordconsdrawbudgettotalVOS) {
        this.recordconsdrawbudgettotalVOS = recordconsdrawbudgettotalVOS;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20220408.085606-74-sources.jar: com/ejianc/business/bedget/vo/ConsdrawbudgettotalVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordconsdrawbudgettotalVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.bedget.vo.ConsdrawbudgettotaldetailVO;

/**
 * 施工预算图汇总表
 * 
 * @author generator
 * 
 */
public class ConsdrawbudgettotalVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.math.BigDecimal costTotal; // 造价合计
    private java.math.BigDecimal itemsSubTotal; // 分部分项合计
    private java.math.BigDecimal measureItemsTotal; // 措施项目合计
    private java.math.BigDecimal otherItemsTotal; // 其他项目合计
    private java.lang.Integer isOpenControl; // 是否开启控制:0 否，1:是
    private java.math.BigDecimal feesTotal; // 规费合计
    private java.math.BigDecimal taxTotal; // 税金合计
    private java.lang.String billCode; // 单据编码
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long operatorId; // 经办人id
    private java.lang.String operatorName; // 经办人名称
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.lang.Long sort; // 序号

    private java.lang.String createTimeShow;
    private java.lang.String billStateStr;
    
    private List<ConsdrawbudgettotaldetailVO> consdrawbudgettotaldetailEntities = new ArrayList<>(); // 施工预算图汇总表子表
    private List<RecordconsdrawbudgettotalVO> recordconsdrawbudgettotalVOS = new ArrayList<>(); // 施工预算图汇总表子表

    /**
     * 造价合计
     */
    public java.math.BigDecimal getCostTotal() {
        return costTotal;
    }

    /**
     * 造价合计
     */
    public void setCostTotal(java.math.BigDecimal costTotal) {
        this.costTotal = costTotal;
    }
    /**
     * 分部分项合计
     */
    public java.math.BigDecimal getItemsSubTotal() {
        return itemsSubTotal;
    }

    /**
     * 分部分项合计
     */
    public void setItemsSubTotal(java.math.BigDecimal itemsSubTotal) {
        this.itemsSubTotal = itemsSubTotal;
    }
    /**
     * 措施项目合计
     */
    public java.math.BigDecimal getMeasureItemsTotal() {
        return measureItemsTotal;
    }

    /**
     * 措施项目合计
     */
    public void setMeasureItemsTotal(java.math.BigDecimal measureItemsTotal) {
        this.measureItemsTotal = measureItemsTotal;
    }
    /**
     * 其他项目合计
     */
    public java.math.BigDecimal getOtherItemsTotal() {
        return otherItemsTotal;
    }

    /**
     * 其他项目合计
     */
    public void setOtherItemsTotal(java.math.BigDecimal otherItemsTotal) {
        this.otherItemsTotal = otherItemsTotal;
    }
    /**
     * 是否开启控制:0 否，1:是
     */
    public java.lang.Integer getIsOpenControl() {
        return isOpenControl;
    }

    /**
     * 是否开启控制:0 否，1:是
     */
    public void setIsOpenControl(java.lang.Integer isOpenControl) {
        this.isOpenControl = isOpenControl;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    
     /**
      * 施工预算图汇总表子表
      */
     public List<ConsdrawbudgettotaldetailVO> getConsdrawbudgettotaldetailEntities() {
        return consdrawbudgettotaldetailEntities;
     }

     /**
      * 施工预算图汇总变更历史记录表
      */
     public void setConsdrawbudgettotaldetailEntities(List<ConsdrawbudgettotaldetailVO> consdrawbudgettotaldetailEntities) {
        this.consdrawbudgettotaldetailEntities = consdrawbudgettotaldetailEntities;
     }

    public List<RecordconsdrawbudgettotalVO> getRecordconsdrawbudgettotalVOS() {
        return recordconsdrawbudgettotalVOS;
    }

    /**
     * 施工预算图汇总变更历史记录表
     */
    public void setRecordconsdrawbudgettotalVOS(List<RecordconsdrawbudgettotalVO> recordconsdrawbudgettotalVOS) {
        this.recordconsdrawbudgettotalVOS = recordconsdrawbudgettotalVOS;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }
}
